boundary.realtime.shell.adapters.jwt-adapter

JWT verification adapter that delegates to boundary/user module.

Wraps boundary.user.shell.auth/validate-jwt-token to provide IJWTVerifier protocol implementation. Avoids direct dependency from core layer to user module.

Responsibilities (Shell/I/O):

  • Call user module for JWT verification (I/O - external dependency)
  • Transform user module response to expected format
  • Handle verification errors
JWT verification adapter that delegates to boundary/user module.

Wraps boundary.user.shell.auth/validate-jwt-token to provide IJWTVerifier
protocol implementation. Avoids direct dependency from core layer to user module.

Responsibilities (Shell/I/O):
- Call user module for JWT verification (I/O - external dependency)
- Transform user module response to expected format
- Handle verification errors
raw docstring

boundary.realtime.shell.adapters.websocket-adapter

WebSocket connection adapter for Ring/Jetty.

Wraps Ring WebSocket implementation to provide IWebSocketConnection protocol. Handles JSON encoding/decoding and WebSocket frame transmission.

Responsibilities (Shell/I/O):

  • Send messages over WebSocket (I/O operation)
  • Close WebSocket connections (I/O operation)
  • JSON encoding (external format transformation)
  • Error handling and logging
WebSocket connection adapter for Ring/Jetty.

Wraps Ring WebSocket implementation to provide IWebSocketConnection protocol.
Handles JSON encoding/decoding and WebSocket frame transmission.

Responsibilities (Shell/I/O):
- Send messages over WebSocket (I/O operation)
- Close WebSocket connections (I/O operation)
- JSON encoding (external format transformation)
- Error handling and logging
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries